==> whois_5.1.2.tar.xz: whois-5.1.2/new_gtlds.h <==
    ".academy",
    ".actor",
    ".agency",
    ".airforce",
    ".archi",
    ".associates",
    ".axa",
    ".bar",
    ".bargains",
    ".berlin",
    ".best",
    ".bid",
    ".bike",
    ".black",
    ".blackfriday",
    ".blue",
    ".boutique",
    ".build",
    ".builders",
    ".buzz",
    ".cab",
    ".camera",
    ".camp",
    ".capital",
    ".cards",
    ".care",
    ".career",
    ".careers",
    ".cash",
    ".catering",
    ".center",
    ".ceo",
    ".cheap",
    ".christmas",
    ".citic",
    ".cleaning",
    ".clinic",
    ".clothing",
    ".club",
    ".codes",
    ".coffee",
    ".college",
    ".cologne",
    ".com",
    ".community",
    ".company",
    ".computer",
    ".condos",
    ".construction",
    ".consulting",
    ".contractors",
    ".cooking",
    ".cool",
    ".country",
    ".creditcard",
    ".cruises",
    ".dance",
    ".dating",
    ".democrat",
    ".dental",
    ".desi",
    ".diamonds",
    ".directory",
    ".discount",
    ".dnp",
    ".domains",
    ".education",
    ".email",
    ".engineering",
    ".enterprises",
    ".equipment",
    ".estate",
    ".eus",
    ".events",
    ".exchange",
    ".expert",
    ".exposed",
    ".fail",
    ".farm",
    ".feedback",
    ".finance",
    ".financial",
    ".fish",
    ".fishing",
    ".fitness",
    ".flights",
    ".florist",
    ".foo",
    ".foundation",
    ".frogans",
    ".fund",
    ".furniture",
    ".futbol",
    ".gal",
    ".gallery",
    ".gift",
    ".glass",
    ".gop",
    ".graphics",
    ".gratis",
    ".gripe",
    ".guitars",
    ".guru",
    ".haus",
    ".holdings",
    ".holiday",
    ".horse",
    ".house",
    ".immobilien",
    ".industries",
    ".info",
    ".ink",
    ".institute",
    ".insure",
    ".international",
    ".investments",
    ".jetzt",
    ".kaufen",
    ".kim",
    ".kitchen",
    ".kiwi",
    ".koeln",
    ".kred",
    ".land",
    ".lease",
    ".lighting",
    ".limited",
    ".limo",
    ".link",
    ".london",
    ".luxury",
    ".maison",
    ".management",
    ".mango",
    ".marketing",
    ".media",
    ".meet",
    ".menu",
    ".miami",
    ".moda",
    ".moe",
    ".monash",
    ".moscow",
    ".nagoya",
    ".net",
    ".neustar",
    ".ninja",
    ".nyc",
    ".okinawa",
    ".onl",
    ".org",
    ".paris",
    ".partners",
    ".parts",
    ".photo",
    ".photography",
    ".photos",
    ".pics",
    ".pictures",
    ".pink",
    ".plumbing",
    ".productions",
    ".properties",
    ".pub",
    ".qpon",
    ".quebec",
    ".recipes",
    ".red",
    ".reisen",
    ".ren",
    ".rentals",
    ".repair",
    ".report",
    ".rest",
    ".reviews",
    ".rich",
    ".rocks",
    ".rodeo",
    ".ruhr",
    ".ryukyu",
    ".saarland",
    ".schule",
    ".services",
    ".sexy",
    ".shiksha",
    ".shoes",
    ".singles",
    ".social",
    ".sohu",
    ".solar",
    ".solutions",
    ".soy",
    ".supplies",
    ".supply",
    ".support",
    ".surgery",
    ".systems",
    ".tattoo",
    ".tax",
    ".technology",
    ".tienda",
    ".tips",
    ".today",
    ".tokyo",
    ".tools",
    ".town",
    ".toys",
    ".trade",
    ".training",
    ".university",
    ".uno",
    ".vacations",
    ".vegas",
    ".ventures",
    ".viajes",
    ".villas",
    ".vision",
    ".vodka",
    ".vote",
    ".voting",
    ".voto",
    ".voyage",
    ".wang",
    ".watch",
    ".webcam",
    ".wed",
    ".wien",
    ".wiki",
    ".works",
    ".wtc",
    ".wtf",
    ".xn--3bst00m",
    ".xn--3ds443g",
    ".xn--55qw42g",
    ".xn--55qx5d",
    ".xn--6frz82g",
    ".xn--6qq986b3xl",
    ".xn--80adxhks",
    ".xn--80asehdb",
    ".xn--80aswg",
    ".xn--c1avg",
    ".xn--cg4bki",
    ".xn--czru2d",
    ".xn--d1acj3b",
    ".xn--fiq228c5hs",
    ".xn--fiq64b",
    ".xn--i1b6b1a6a2e",
    ".xn--io0a7i",
    ".xn--mgbab2bd",
    ".xn--ngbc5azd",
    ".xn--nqv7f",
    ".xn--nqv7fs00ema",
    ".xn--q9jyb4c",
    ".xn--rhqv96g",
    ".xn--ses554g",
    ".xn--unup4y",
    ".xn--zfr164b",
    ".xyz",
    ".yokohama",
    ".zone",

==> whois_5.1.4.tar.xz: whois-5.1.4/new_gtlds.h <==
    ".academy",
    ".accountants",
    ".actor",
    ".agency",
    ".airforce",
    ".archi",
    ".associates",
    ".audio",
    ".autos",
    ".axa",
    ".bar",
    ".bargains",
    ".bayern",
    ".beer",
    ".berlin",
    ".best",
    ".bid",
    ".bike",
    ".black",
    ".blackfriday",
    ".blue",
    ".boutique",
    ".build",
    ".builders",
    ".buzz",
    ".cab",
    ".camera",
    ".camp",
    ".capital",
    ".cards",
    ".care",
    ".career",
    ".careers",
    ".cash",
    ".catering",
    ".center",
    ".ceo",
    ".cheap",
    ".christmas",
    ".church",
    ".citic",
    ".claims",
    ".cleaning",
    ".clinic",
    ".clothing",
    ".club",
    ".codes",
    ".coffee",
    ".college",
    ".cologne",
    ".com",
    ".community",
    ".company",
    ".computer",
    ".condos",
    ".construction",
    ".consulting",
    ".contractors",
    ".cooking",
    ".cool",
    ".country",
    ".credit",
    ".creditcard",
    ".cruises",
    ".dance",
    ".dating",
    ".democrat",
    ".dental",
    ".desi",
    ".diamonds",
    ".digital",
    ".directory",
    ".discount",
    ".dnp",
    ".domains",
    ".education",
    ".email",
    ".engineering",
    ".enterprises",
    ".equipment",
    ".estate",
    ".eus",
    ".events",
    ".exchange",
    ".expert",
    ".exposed",
    ".fail",
    ".farm",
    ".feedback",
    ".finance",
    ".financial",
    ".fish",
    ".fishing",
    ".fitness",
    ".flights",
    ".florist",
    ".foo",
    ".foundation",
    ".frogans",
    ".fund",
    ".furniture",
    ".futbol",
    ".gal",
    ".gallery",
    ".gift",
    ".glass",
    ".globo",
    ".gmo",
    ".gop",
    ".graphics",
    ".gratis",
    ".gripe",
    ".guide",
    ".guitars",
    ".guru",
    ".haus",
    ".hiphop",
    ".holdings",
    ".holiday",
    ".homes",
    ".horse",
    ".house",
    ".immobilien",
    ".industries",
    ".info",
    ".ink",
    ".institute",
    ".insure",
    ".international",
    ".investments",
    ".jetzt",
    ".juegos",
    ".kaufen",
    ".kim",
    ".kitchen",
    ".kiwi",
    ".koeln",
    ".kred",
    ".land",
    ".lease",
    ".life",
    ".lighting",
    ".limited",
    ".limo",
    ".link",
    ".loans",
    ".london",
    ".luxe",
    ".luxury",
    ".maison",
    ".management",
    ".mango",
    ".marketing",
    ".media",
    ".meet",
    ".menu",
    ".miami",
    ".moda",
    ".moe",
    ".monash",
    ".moscow",
    ".motorcycles",
    ".nagoya",
    ".net",
    ".neustar",
    ".ninja",
    ".nyc",
    ".okinawa",
    ".onl",
    ".org",
    ".paris",
    ".partners",
    ".parts",
    ".photo",
    ".photography",
    ".photos",
    ".pics",
    ".pictures",
    ".pink",
    ".plumbing",
    ".productions",
    ".properties",
    ".pub",
    ".qpon",
    ".quebec",
    ".recipes",
    ".red",
    ".reise",
    ".reisen",
    ".ren",
    ".rentals",
    ".repair",
    ".report",
    ".rest",
    ".reviews",
    ".rich",
    ".rio",
    ".rocks",
    ".rodeo",
    ".ruhr",
    ".ryukyu",
    ".saarland",
    ".schule",
    ".services",
    ".sexy",
    ".shiksha",
    ".shoes",
    ".singles",
    ".social",
    ".sohu",
    ".solar",
    ".solutions",
    ".soy",
    ".supplies",
    ".supply",
    ".support",
    ".surgery",
    ".systems",
    ".tattoo",
    ".tax",
    ".technology",
    ".tienda",
    ".tips",
    ".today",
    ".tokyo",
    ".tools",
    ".town",
    ".toys",
    ".trade",
    ".training",
    ".university",
    ".uno",
    ".vacations",
    ".vegas",
    ".ventures",
    ".versicherung",
    ".viajes",
    ".villas",
    ".vision",
    ".vodka",
    ".vote",
    ".voting",
    ".voto",
    ".voyage",
    ".wang",
    ".watch",
    ".webcam",
    ".wed",
    ".wien",
    ".wiki",
    ".works",
    ".wtc",
    ".wtf",
    ".xn--3bst00m",
    ".xn--3ds443g",
    ".xn--55qw42g",
    ".xn--55qx5d",
    ".xn--6frz82g",
    ".xn--6qq986b3xl",
    ".xn--80adxhks",
    ".xn--80asehdb",
    ".xn--80aswg",
    ".xn--c1avg",
    ".xn--cg4bki",
    ".xn--czr694b",
    ".xn--czru2d",
    ".xn--d1acj3b",
    ".xn--fiq228c5hs",
    ".xn--fiq64b",
    ".xn--i1b6b1a6a2e",
    ".xn--io0a7i",
    ".xn--mgbab2bd",
    ".xn--ngbc5azd",
    ".xn--nqv7f",
    ".xn--nqv7fs00ema",
    ".xn--q9jyb4c",
    ".xn--rhqv96g",
    ".xn--ses554g",
    ".xn--unup4y",
    ".xn--zfr164b",
    ".xyz",
    ".yachts",
    ".yokohama",
    ".zone",
